@@ -14,10 +14,10 @@ data_logger = TensorboardLogger()
 
 env_name = 'CartPole-v1'
 task = GymTask(env_name, seed=seed)
-agent = DQNAgent(task.state_size, task.action_size, n_steps=5, seed=seed, device="cuda")
+agent = DQNAgent(task.state_size, task.action_size, n_steps=5, seed=seed)
 env_runner = EnvRunner(task, agent, data_logger=data_logger, seed=seed)
 
-scores = env_runner.run(reward_goal=100, max_episodes=300, force_new=True, eps_decay=0.99, gif_every_episodes=5)
+scores = env_runner.run(reward_goal=100, max_episodes=300, force_new=True)
 env_runner.interact_episode(render=True)
 
 # plot the scores
